==> 0.1.0.tar.gz: lib/src/actor.dart <==
library theater.actor;

import 'dart:async';
import 'dart:collection';
import 'dart:core';
import 'dart:isolate';
import 'dart:math';

import 'package:theater/src/dispatch.dart';
import 'package:theater/src/routing.dart';
import 'package:theater/src/util.dart';

part 'actor/isolate/isolate_error.dart';
part 'actor/actor_event.dart';
part 'actor/actor_action.dart';
part 'actor/isolate/isolate_spawn_message.dart';
part 'actor/isolate/isolate_supervisor.dart';
part 'actor/exception/isolate_supervisor_exception.dart';
part 'actor/isolate/isolate_context.dart';

part 'actor/supervisor_strategy/directive.dart';
part 'actor/supervisor_strategy/supervisor_strategy.dart';
part 'actor/supervisor_strategy/all_for_one_strategy.dart';
part 'actor/supervisor_strategy/one_for_one_strategy.dart';
part 'actor/supervisor_strategy/decider.dart';
part 'actor/supervisor_strategy/default_decider.dart';

part 'actor/exception/actor_child_exception.dart';
part 'actor/exception/actor_system_exception.dart';
part 'actor/exception/actor_context_exception.dart';
part 'actor/exception/pool_deployement_strategy_exception.dart';

part 'actor/actor.dart';
part 'actor/actor_cell.dart';
part 'actor/actor_cell_factory.dart';
part 'actor/actor_context.dart';
part 'actor/actor_isolate_handler.dart';
part 'actor/supervisor_strategy/supervisor_strategy_creater.dart';
part 'actor/actor_context_factory.dart';
part 'actor/actor_isolate_handler_factory.dart';
part 'actor/actor_error.dart';
part 'actor/actor_properties.dart';
part 'actor/actor_message_sender.dart';
part 'actor/actor_ref_factory.dart';
part 'actor/actor_system.dart';
part 'actor/actor_cell_factory_creater.dart';
part 'actor/actor_cell_properties.dart';
part 'actor/actor_parent.dart';
part 'actor/node_actor_ref_factory.dart';
part 'actor/actor_message_receiver.dart';
part 'actor/actor_factory.dart';

part 'actor/supervisor_actor/supervisor_actor.dart';
part 'actor/supervisor_actor/supervisor_actor_cell.dart';
part 'actor/supervisor_actor/supervisor_actor_cell_factory.dart';
part 'actor/supervisor_actor/supervisor_actor_cell_properties.dart';
part 'actor/supervisor_actor/supervisor_actor_properties.dart';
part 'actor/supervisor_actor/supervisor_actor_context.dart';
part 'actor/supervisor_actor/supervisor_actor_context_factory.dart';
part 'actor/supervisor_actor/supervisor_actor_isolate_handler.dart';
part 'actor/supervisor_actor/supervisor_actor_isolate_handler_factory.dart';

part 'actor/observable_actor/observable_actor.dart';
part 'actor/observable_actor/observable_actor_cell.dart';
part 'actor/observable_actor/observable_actor_cell_factory.dart';
part 'actor/observable_actor/observable_actor_cell_properties.dart';
part 'actor/observable_actor/observable_actor_context.dart';
part 'actor/observable_actor/observable_actor_context_factory.dart';
part 'actor/observable_actor/observable_actor_isolate_handler.dart';
part 'actor/observable_actor/observable_actor_isolate_handler_factory.dart';
part 'actor/observable_actor/observable_actor_properties.dart';
part 'actor/observable_actor/observable_actor_factory.dart';

part 'actor/root_actor/root_actor.dart';
part 'actor/root_actor/root_actor_cell.dart';
part 'actor/root_actor/root_actor_context.dart';
part 'actor/root_actor/root_actor_context_factory.dart';
part 'actor/root_actor/root_actor_isolate_handler.dart';
part 'actor/root_actor/root_actor_isolate_handler_factory.dart';
part 'actor/root_actor/root_actor_properties.dart';
part 'actor/root_actor/default_root_actor.dart';

part 'actor/node_actor/node_actor.dart';
part 'actor/node_actor/node_actor_cell.dart';
part 'actor/node_actor/node_actor_cell_factory.dart';
part 'actor/node_actor/node_actor_cell_properties.dart';
part 'actor/node_actor/node_actor_context.dart';
part 'actor/node_actor/node_actor_context_factory.dart';
part 'actor/node_actor/node_actor_isolate_handler.dart';
part 'actor/node_actor/node_actor_isolate_handler_factory.dart';
part 'actor/node_actor/node_actor_properties.dart';

part 'actor/sheet_actor/sheet_actor.dart';
part 'actor/sheet_actor/sheet_actor_cell.dart';
part 'actor/sheet_actor/sheet_actor_cell_factory.dart';
part 'actor/sheet_actor/sheet_actor_cell_properties.dart';
part 'actor/sheet_actor/sheet_actor_context.dart';
part 'actor/sheet_actor/sheet_actor_context_factory.dart';
part 'actor/sheet_actor/sheet_actor_isolate_handler.dart';
part 'actor/sheet_actor/sheet_actor_isolate_handler_factory.dart';
part 'actor/sheet_actor/sheet_actor_properties.dart';

part 'actor/untyped_actor/untyped_actor.dart';
part 'actor/untyped_actor/untyped_actor_cell.dart';
part 'actor/untyped_actor/untyped_actor_cell_factory.dart';
part 'actor/untyped_actor/untyped_actor_context.dart';
part 'actor/untyped_actor/untyped_actor_context_factory.dart';
part 'actor/untyped_actor/untyped_actor_isolate_handler.dart';
part 'actor/untyped_actor/untyped_actor_isolate_handler_factory.dart';
part 'actor/untyped_actor/untyped_actor_properties.dart';

part 'actor/router_actor/router_actor.dart';
part 'actor/router_actor/router_actor_cell.dart';
part 'actor/router_actor/router_actor_cell_factory.dart';
part 'actor/router_actor/router_actor_context.dart';
part 'actor/router_actor/router_actor_context_factory.dart';
part 'actor/router_actor/router_actor_isolate_handler.dart';
part 'actor/router_actor/router_actor_isolate_handler_factory.dart';
part 'actor/router_actor/router_actor_properties.dart';

part 'actor/router_actor/group_router_actor/group_router_actor.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_context.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_context_factory.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_properties.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_cell.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_cell_factory.dart';
part 'actor/router_actor/group_router_actor/test_group_router_actor_context.dart';

part 'actor/router_actor/pool_router_actor/pool_router_actor.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_context.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_context_factory.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_properties.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_cell.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_cell_factory.dart';
part 'actor/router_actor/pool_router_actor/test_pool_router_actor_context.dart';

part 'actor/router_actor/deployement_strategy/group_deployement_strategy/group_deployement_strategy.dart';
part 'actor/router_actor/deployement_strategy/group_deployement_strategy/actor_info.dart';
part 'actor/router_actor/deployement_strategy/pool_deployement_strategy.dart';
part 'actor/router_actor/deployement_strategy/router_deployement_strategy.dart';

part 'actor/worker_actor/worker_actor.dart';
part 'actor/worker_actor/worker_actor_cell.dart';
part 'actor/worker_actor/worker_actor_cell_factory.dart';
part 'actor/worker_actor/worker_actor_context.dart';
part 'actor/worker_actor/worker_actor_context_factory.dart';
part 'actor/worker_actor/worker_actor_isolate_handler.dart';
part 'actor/worker_actor/worker_actor_isolate_handler_factory.dart';
part 'actor/worker_actor/worker_actor_properties.dart';
part 'actor/worker_actor/worker_actor_factory.dart';
part 'actor/worker_actor/worker_actor_event.dart';
part 'actor/worker_actor/worker_actor_cell_properties.dart';

part 'actor/actor_guardian/system_guardian/system_guardian.dart';

part 'actor/actor_guardian/user_guardian/user_guardian.dart';

==> 0.2.21.tar.gz: lib/src/actor.dart <==
library theater.actor;

import 'dart:async';
import 'dart:core';
import 'dart:isolate';
import 'dart:math';

import 'actor_system.dart';
import 'supervising.dart';
import 'dispatch.dart';
import 'remote.dart';
import 'routing.dart';
import 'util.dart';
import 'core.dart';
import 'isolate.dart';

part 'actor/exception/actor_child_exception.dart';
part 'actor/exception/actor_system_exception.dart';
part 'actor/exception/actor_context_exception.dart';
part 'actor/exception/pool_deployement_strategy_exception.dart';
part 'actor/exception/actor_data_store_exception.dart';

part 'actor/actor.dart';
part 'actor/actor_cell.dart';
part 'actor/actor_cell_factory.dart';
part 'actor/actor_context.dart';
part 'actor/actor_isolate_handler.dart';
part 'actor/actor_context_builder.dart';
part 'actor/actor_isolate_handler_factory.dart';
part 'actor/actor_error.dart';
part 'actor/actor_properties.dart';
part 'actor/actor_message_sender.dart';
part 'actor/actor_ref_factory.dart';
part 'actor/actor_cell_factory_creater.dart';
part 'actor/actor_cell_properties.dart';
part 'actor/actor_parent_mixin.dart';
part 'actor/node_actor_ref_factory_mixin.dart';
part 'actor/actor_message_receiver_mixin.dart';
part 'actor/actor_factory.dart';
part 'actor/actor_data_store.dart';
part 'actor/actor_event.dart';
part 'actor/actor_action.dart';

part 'actor/user_actor_cell_mixin.dart';
part 'actor/user_actor_context_mixin.dart';

part 'actor/supervisor_actor/supervisor_actor.dart';
part 'actor/supervisor_actor/supervisor_actor_cell.dart';
part 'actor/supervisor_actor/supervisor_actor_cell_factory.dart';
part 'actor/supervisor_actor/supervisor_actor_cell_properties.dart';
part 'actor/supervisor_actor/supervisor_actor_properties.dart';
part 'actor/supervisor_actor/supervisor_actor_context.dart';
part 'actor/supervisor_actor/supervisor_actor_context_builder.dart';
part 'actor/supervisor_actor/supervisor_actor_isolate_handler.dart';
part 'actor/supervisor_actor/supervisor_actor_isolate_handler_factory.dart';

part 'actor/observable_actor/observable_actor.dart';
part 'actor/observable_actor/observable_actor_cell.dart';
part 'actor/observable_actor/observable_actor_cell_factory.dart';
part 'actor/observable_actor/observable_actor_cell_properties.dart';
part 'actor/observable_actor/observable_actor_context.dart';
part 'actor/observable_actor/observable_actor_context_builder.dart';
part 'actor/observable_actor/observable_actor_isolate_handler.dart';
part 'actor/observable_actor/observable_actor_isolate_handler_factory.dart';
part 'actor/observable_actor/observable_actor_properties.dart';
part 'actor/observable_actor/observable_actor_factory.dart';

part 'actor/root_actor/root_actor.dart';
part 'actor/root_actor/root_actor_cell.dart';
part 'actor/root_actor/root_actor_context.dart';
part 'actor/root_actor/root_actor_context_builder.dart';
part 'actor/root_actor/root_actor_isolate_handler.dart';
part 'actor/root_actor/root_actor_isolate_handler_factory.dart';
part 'actor/root_actor/root_actor_properties.dart';

part 'actor/node_actor/node_actor.dart';
part 'actor/node_actor/node_actor_cell.dart';
part 'actor/node_actor/node_actor_cell_factory.dart';
part 'actor/node_actor/node_actor_cell_properties.dart';
part 'actor/node_actor/node_actor_context.dart';
part 'actor/node_actor/node_actor_context_builder.dart';
part 'actor/node_actor/node_actor_isolate_handler.dart';
part 'actor/node_actor/node_actor_isolate_handler_factory.dart';
part 'actor/node_actor/node_actor_properties.dart';

part 'actor/sheet_actor/sheet_actor.dart';
part 'actor/sheet_actor/sheet_actor_cell.dart';
part 'actor/sheet_actor/sheet_actor_cell_factory.dart';
part 'actor/sheet_actor/sheet_actor_cell_properties.dart';
part 'actor/sheet_actor/sheet_actor_context.dart';
part 'actor/sheet_actor/sheet_actor_context_builder.dart';
part 'actor/sheet_actor/sheet_actor_isolate_handler.dart';
part 'actor/sheet_actor/sheet_actor_isolate_handler_factory.dart';
part 'actor/sheet_actor/sheet_actor_properties.dart';

part 'actor/untyped_actor/untyped_actor.dart';
part 'actor/untyped_actor/untyped_actor_cell.dart';
part 'actor/untyped_actor/untyped_actor_cell_factory.dart';
part 'actor/untyped_actor/untyped_actor_context.dart';
part 'actor/untyped_actor/untyped_actor_context_factory.dart';
part 'actor/untyped_actor/untyped_actor_isolate_handler.dart';
part 'actor/untyped_actor/untyped_actor_isolate_handler_factory.dart';
part 'actor/untyped_actor/untyped_actor_properties.dart';

part 'actor/router_actor/router_actor.dart';
part 'actor/router_actor/router_actor_cell.dart';
part 'actor/router_actor/router_actor_cell_factory.dart';
part 'actor/router_actor/router_actor_context.dart';
part 'actor/router_actor/router_actor_context_factory.dart';
part 'actor/router_actor/router_actor_isolate_handler.dart';
part 'actor/router_actor/router_actor_isolate_handler_factory.dart';
part 'actor/router_actor/router_actor_properties.dart';

part 'actor/router_actor/group_router_actor/group_router_actor.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_context.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_context_builder.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_properties.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_cell.dart';
part 'actor/router_actor/group_router_actor/group_router_actor_cell_factory.dart';

part 'actor/router_actor/pool_router_actor/pool_router_actor.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_context.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_context_builder.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_properties.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_cell.dart';
part 'actor/router_actor/pool_router_actor/pool_router_actor_cell_factory.dart';

part 'actor/router_actor/deployement_strategy/group_deployement_strategy/group_deployement_strategy.dart';
part 'actor/router_actor/deployement_strategy/group_deployement_strategy/actor_info.dart';
part 'actor/router_actor/deployement_strategy/pool_deployement_strategy.dart';
part 'actor/router_actor/deployement_strategy/router_deployement_strategy.dart';

part 'actor/worker_actor/worker_actor.dart';
part 'actor/worker_actor/worker_actor_cell.dart';
part 'actor/worker_actor/worker_actor_cell_factory.dart';
part 'actor/worker_actor/worker_actor_context.dart';
part 'actor/worker_actor/worker_actor_context_factory.dart';
part 'actor/worker_actor/worker_actor_isolate_handler.dart';
part 'actor/worker_actor/worker_actor_isolate_handler_factory.dart';
part 'actor/worker_actor/worker_actor_properties.dart';
part 'actor/worker_actor/worker_actor_factory.dart';
part 'actor/worker_actor/worker_actor_event.dart';
part 'actor/worker_actor/worker_actor_cell_properties.dart';

part 'actor/system_actor/system_actor.dart';
part 'actor/system_actor/system_actor_cell.dart';
part 'actor/system_actor/system_actor_cell_factory.dart';
part 'actor/system_actor/system_actor_context.dart';
part 'actor/system_actor/system_actor_context_builder.dart';
part 'actor/system_actor/system_actor_isolate_handler.dart';
part 'actor/system_actor/system_actor_isolate_handler_factory.dart';
part 'actor/system_actor/system_actor_properties.dart';
